@@ -5,12 +5,13 @@ package Win32::NetAdmin;
 #Written by Douglas_Lankshear@ActiveWare.com
 #
 
-$VERSION = '0.06';
+$VERSION = '0.08';
 
 require Exporter;
 require DynaLoader;
 
-die "The Win32::NetAdmin module works only on Windows NT" if(!Win32::IsWinNT() );
+require Win32 unless defined &Win32::IsWinNT;
+die "The Win32::NetAdmin module works only on Windows NT" unless Win32::IsWinNT();
 
 @ISA= qw( Exporter DynaLoader );
 # Items to export into callers namespace by default. Note: do not export
@@ -145,12 +146,19 @@ network.
 
 =head2 NOTE
 
-All of the functions return FALSE (0) if they fail, unless otherwise noted.
+All of the functions return false if they fail, unless otherwise noted.
+When a function fails call Win32::NetAdmin::GetError() rather than
+GetLastError() or $^E to retrieve the error code.
+
 C<server> is optional for all the calls below. If not given the local machine is
 assumed.
 
 =over 10
 
+=item GetError()
+
+Returns the error code of the last call to this module.
+
 =item GetDomainController(server, domain, returnedName)
 
 Returns the name of the domain controller for server.
@@ -323,14 +331,59 @@ contains two-character strings (drive letter followed by a colon).
 
 =back
 
+=head1 EXAMPLE
+
+    # Simple script using Win32::NetAdmin to set the login script for
+    # all members of the NT group "Domain Users".  Only works if you
+    # run it on the PDC. (From Robert Spier <rspier@seas.upenn.edu>)
+    #
+    # FILTER_TEMP_DUPLICATE_ACCOUNTS
+    #	Enumerates local user account data on a domain controller.
+    #
+    # FILTER_NORMAL_ACCOUNT
+    #	Enumerates global user account data on a computer.
+    #
+    # FILTER_INTERDOMAIN_TRUST_ACCOUNT
+    #	Enumerates domain trust account data on a domain controller.
+    #
+    # FILTER_WORKSTATION_TRUST_ACCOUNT
+    #	Enumerates workstation or member server account data on a domain
+    #	controller.
+    #
+    # FILTER_SERVER_TRUST_ACCOUNT
+    #	Enumerates domain controller account data on a domain controller.
+
+
+    use Win32::NetAdmin qw(GetUsers GroupIsMember
+			   UserGetAttributes UserSetAttributes);
+
+    my %hash;
+    GetUsers("", FILTER_NORMAL_ACCOUNT , \%hash)
+	or die "GetUsers() failed: $^E";
+
+    foreach (keys %hash) {
+	my ($password, $passwordAge, $privilege,
+	    $homeDir, $comment, $flags, $scriptPath);
+	if (GroupIsMember("", "Domain Users", $_)) {
+	    print "Updating $_ ($hash{$_})\n";
+	    UserGetAttributes("", $_, $password, $passwordAge, $privilege,
+			      $homeDir, $comment, $flags, $scriptPath)
+		or die "UserGetAttributes() failed: $^E";
+	    $scriptPath = "dnx_login.bat"; # this is the new login script
+	    UserSetAttributes("", $_, $password, $passwordAge, $privilege,
+			      $homeDir, $comment, $flags, $scriptPath)
+		or die "UserSetAttributes() failed: $^E";
+	}
+    }
+
 =cut
 
 sub AUTOLOAD {
     my($constname);
     ($constname = $AUTOLOAD) =~ s/.*:://;
     #reset $! to zero to reset any current errors.
-    $!=0;
-    my $val = constant($constname, @_ ? $_[0] : 0);
+    local $! = 0;
+    my $val = constant($constname);
     if ($! != 0) {
 	if ($! =~ /Invalid/) {
 	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
@@ -354,6 +407,11 @@ $SidTypeDeletedAccount = 6;
 $SidTypeInvalid = 7;
 $SidTypeUnknown = 8;
 
+sub GetError() {
+    our $__lastError;
+    $__lastError;
+}
+
 bootstrap Win32::NetAdmin;
 
 1;
